/*
Example 5: Multiple Regression -- biological response to temperature.

Growth of Colletotrichum coccodes on PDA at different temperatures.

t:		temperature (C)
isolE:	linear growth rate on PDA for isolate E
isolS:	linear growth rate on PDA for isolate S
growth:	re-names response variable (growth rate of selected isolate [S])

*/
data T;
input t isolE isolS @@;
growth=isolS;
datalines;
5.0 0.0 0.5   	7.5 1.0 1.0   	10.0 6.3 6.3   12.5 10.0 11.8   15.0 13.1 15.1   
17.5 16.7 19.5   20.0 23.3 25.9   
22.5 28.3 31.1   25.0 31.6 37.3   26.5 34.1 40.3   27.5 31.7 38.6   
28.5 30.3 38.6   29.0 29.0 35.4
30.0 25.1 31.6   32.5 23.0 19.5   33.5 12.8 9.2   35.0 2.0 0.0 
;
title 'Growth of Colletotrichum on PDA';
proc print data=t;
run;
goptions reset=all;
axis1 w=3 order= (2 to 38 by 4 ) minor=none value= (font=swiss h=2)
	label= (f=swiss h=2 'Temperature (C)');
axis2 w=3 order= (0 to 45 by 9) minor=none value=(font=swiss h=2)
	label= (angle=90 f=swiss h=2 'Mycelial growth');
proc gplot data=t;
	title2 'Graph of the growth rate';
	symbol1 v=dot color=blue w=1.5 h=1.6;
	plot growth*T / haxis=axis1 vaxis=axis2;
run;

data t; set t;				*<--consider some powers of temperature, etc.;
	srgrowth=sqrt(growth);
	lgrowth=log(growth+1);
	t12=sqrt(t);
	t2= t**2;
	t3=t**3;
	t4=t**4;
	lt=log(t+.1);
	lt2=lt**2;
	ltnl = log(t);
	ltnh = log(36-t);
	wt= growth+1;
	wt2=growth**2;
run;
	*ods html;
	*ods graphics on;
proc reg data=t;
	title2 'Quadratic model (T and T^2)';
	model growth = t t2 / r influence clb;
	plot rstudent.*p.;
	output out=t_out p=growthhat r=r;
run;

data t_out; set t_out;
	*growthhat=exp(growthhat);
proc print data=t_out;run;
proc gplot data=t_out;
	symbol1 v=dot color=blue w=1.5 i=none h=1.6;
	symbol2 v=none color=red w=2 i=join;
	plot (growth growthhat)*T / overlay haxis=axis1 vaxis=axis2;
run;

	ods graphics off;
	ods html close;
run;

*---Above, try other two-variable models, where the each variable is a power
	of temperature. There is a best choice.;

proc reg data=t;
	title2 'Two-power model (T^3 and T^4)';
	model growth = t3 t4 / r influence clb;
	plot rstudent.*p.;
	plot r.*p.;
	output out=t_out p=growthhat r=r;
run;
proc print data=t_out;run;
proc gplot data=t_out;
	symbol1 v=dot color=blue w=1.5 i=none h=1.6;
	symbol2 v=none color=red w=2 i=join;
	plot (growth growthhat)*T / overlay haxis=axis1 vaxis=axis2;
run;

/*

*---As an aside, below is a very good way of describing temperature responses.
	This is based on the so-called nonlinear Beta model. There are several papers
	by Madden and colleagues (especially in the 1980s and 90s) using this. It is converted
	to linear by logs (both sides), and fitted with weights (with weight = growth^2).
	One must back-transform the log predictions to see the predictions of growth.
	This is demonstrated below.;
proc reg data=t;
	title2 'Beta nonlinear model, linearized, with weights';
	weight wt2;
	model lgrowth = ltnl ltnh ;
	output out=t_out2 p=growthhat r=r;
run;
data t_out2; set t_out2;
	growthhat=exp(growthhat);
	rgrowth=growth-growthhat;
proc print data=t_out;run;
proc gplot data=t_out2;
	symbol1 v=dot color=blue w=1.5 i=none;
	symbol2 v=none color=red w=2 i=join;
	plot (growth growthhat)*T / overlay haxis=axis1 vaxis=axis2;
run;

*/

/*
*---One can write the cubic-quartic model, beta0 + beta3.T**3 - beta4.T**4, as
	beta0 + b.T**3(1 - c.T) , where b=beta3 and c=(beta4/beta3).
	Below is one way to fit this as a nonlinear model (although not needed, since
	it is really a linear model.;
proc nlin data=t;
title2 'test of nonlinear version of 3-4 model';
parms beta0 0 b .0086 c .0286;
model growth = beta0 + b*(t**3)*(1 - c*(t**1)) ;
output out=nlinout p=grohat;
run;
proc gplot data=nlinout;
	symbol1 v=dot color=blue w=1.5 i=none;
	symbol2 v=none color=black w=1.5 i=join;
	plot (growth grohat)*T / overlay haxis=axis1 vaxis=axis2;
run;
*/
run;

